from typing import Any, Dict


def reader(path: str, extension: str, **kwargs):
    """
    Wrapper for various methods to read data from a file

    :param path: file's path.
    :param extension: files format.
    available formats are:
    - "text"
    - "json"
    - "pickle"
    :param kwargs dictionary of other options.
    available options are:
    -
    :return: content of file
    """

    if extension == "text":
        return text_reader(path, **kwargs)


def text_reader(path: str, **kwargs):
    """ Reads in all of a textual file """

    # default settings
    config: Dict[str, Any] = dict(encoding="utf-8", readlines=False, max_length=-1, max_lines=None,
                                  line_step=1)

    # modify settings with user provided values in kwargs
    for key in config.keys():
        if key in kwargs:
            config[key] = kwargs[key]

    with open(path, 'r', encoding=config["encoding"]) as file:
        if config["readlines"]:
            data = file.readlines(config["max_length"])
            if config["max_lines"]:
                data = [data[line] for line in range(0, config["max_lines"], config["line_step"])]
            elif config["line_step"] != 1:
                data = [data[line] for line in range(0, len(data), config["line_step"])]
        else:
            data = file.read(config["max_length"])
    return data



from setuptools import setup, find_packages


setup(
    name="ErfanIO",
    version="0.0.4",
    packages=find_packages(),
    url="https://gitlab.com/Azadeh-Afzar/Utility-Development/ErfanIO",
    license="AGPL-3.0",
    author="Mohammad Mahdi Baghbani Pourvahid",
    author_email="MahdiBaghbani@protonmail.com",
    description="Simple and painless IO library",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "License :: OSI Approved :: zlib/libpng License",
        "Topic :: Software Development",
        "Topic :: Utilities",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7"
    ]
)
